from __future__ import absolute_import

import os
import pkg_resources as _pkg_resources
from py_zillow.zillow._version import __version__

from py_zillow.zillow.api.api import ValuationAPI
import py_zillow.zillow.config.secrets as secrets

__author__ = 'alex@freightroll.com'

os.environ['zws_id'] = secrets.zws_id()
zillow = ValuationAPI()


import setuptools
from py_zillow.zillow._version import __version__

with open('README.md', 'r') as f:
    long_description = f.read()

setuptools.setup(
    name = 'py-zillow',
    version = __version__,
    license = "MIT",
    author = 'Alexander Dewhirst',
    author_email = 'alex@freightroll.com',
    description = 'A Zillow API wrapper',
    long_description = long_description,
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/AlexanderDewhirst/py-zillow',
    keywords = ['zillow', 'api', 'real estate', 'python'],
    packages = setuptools.find_packages(),
    classifiers = [
        "Programming Language :: Python :: 3"
    ],
)